// This contains several new objectives for AI control
//
$AIWeightSatchel[1] = 2900;  // Not used yet ref only

$AIWeightMissileObject[1]      = 3500;	//range 3500 to 3600
$AIWeightMissileObject[2]      = 1100;	//range 1100 to 1320

activatePackage(Bot_Satchel);
activatePackage(Missile_Target);
//******************************************************************************
//***** Bot Satchel Objective Package
//******************************************************************************
package Bot_Satchel {
//==============================================================================
//  AIObjectiveSatchel
//==============================================================================
function AIOBlowUP::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AISatchel);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOBlowUP::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}

// this is taken from defend object to check if the object is distroyed
function AIOBlowUP::weight(%objective, %client, %level, %minWeight)
{
   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;
   // check who owns this
   if (%this.targetObjectId > 0)
	{
   	if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team != %client.team)
	      return 0;
	}

	//do a quick check to disqualify this objective if it can't meet the minimum weight
	if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
	{
		if (%this.targetObjectId > 0 && %this.issuedByClientId == %client.controlByHuman)
		{
			if ($AIWeightHumanIssuedCommand < %minWeight)
				return 0;
		}
		else
			return 0;
	}

	%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);

   //if the object has been destroyed, reduce the weight
	if (%this.targetObjectId > 0)
	{

		//see if we were forced on the objective
		if (%this.issuedByClientId == %client.controlByHuman && %weight < $AIWeightHumanIssuedCommand)
			%weight = $AIWeightHumanIssuedCommand;

		//else see if the object has been destroyed
	   else if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
			%weight = 0;
	}

	return %weight;
}
//------------------------------------------------------------------------------
// Ok it gets tricky here

function AISatchel::initFromObjective(%task, %objective, %client)
{
	//initialize the task vars from the objective
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;

	if (%objective.Location !$= "")
	   %task.location = %objective.location;
	else
	   %task.location = %objective.targetObjectId.getWorldBoxCenter();

   %task.equipment = %objective.equipment;
   %task.buyEquipmentSet = %objective.buyEquipmentSet;
   %task.desiredEquipment = %objective.desiredEquipment;
   %task.issuedByClient = %objective.issuedByClientId;
   %task.chat = %objective.chat;

   if (%task.chat ="")
         %task.chat ="AttackBase ChatCmdAttack";
	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
   %player = %client.player;
   %player.thrownChargeId = 0;
}

function AISatchel::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(15);
//   %client.inPerimeter = false;
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);

   //mark the current time for the buy inventory state machine
   %task.buyInvTime = getSimTime();
}

function AISatchel::retire(%task, %client)
{
	%task.engageVehicle = -1;
	%client.setTargetObject(-1);
}

function AISatchel::weight(%task, %client)
{
   %task.setWeightFreq(100);
   %task.setMonitorFreq(30);
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   %task.setWeight(%task.baseWeight);
}

function AISatchel::monitor(%task, %client)
{
//   trace(1);
//   error("----ON enter Satchel Blow client "@%client);
//   error("----Client obj #"@ %client.objective);
   //first, buy the equipment
   if (%client.needEquipment)
   {
//   error("----Need Equipment");
	   %task.setMonitorFreq(30);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
//   error("----Need Equipment Result "@%result);

		if (%result $= "InProgress")
			return;
		else if (%result $= "Finished")
		{
		   %task.setMonitorFreq(100);
         %client.needEquipment = false;
         //if we made it past the inventory buying, reset the inv time
	      %task.buyInvTime = getSimTime();
      }
      else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
//              error("----Satchel Buy Inventory Failed "@ %client.objective);
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }
   //see if we're supposed to be engaging anyone...
   if (AIClientIsAlive(%client.shouldEngage))
   {
	   %hasLOS = %client.hasLOSToClient(%client.shouldEngage);
	   %losTime = %client.getClientLOSTime(%client.shouldEngage);
	   if (%hasLOS || %losTime < 1000)
         %client.setEngageTarget(%client.shouldEngage);
      else
         %client.setEngageTarget(-1);
   }
   else
      %client.setEngageTarget(-1);

	//if the location task has an object
	if (%task == %client.objectiveTask && isObject(%task.targetObject))
	{
		if (%task.targetObject.getDamageState() $= "Destroyed")
          {
//            error("----Satchel Target Destroyed"@ %client.objective);
            AIUnassignClient(%client);
            Game.AIChooseGameObjective(%client);
				return;
		}
	}

    // Can I deploy my satchel?  5 meters
       %player = %client.player;
	%dist = VectorDist(%player.getWorldBoxCenter(), %task.location);
    // Ok someday I will come up with a realy code
//    echo("----Satchel Target Dist"@ %dist);

    if (%dist < 7 && !%player.thrownChargeId)
    {
       %client.aimAt(%task.location,20);
       %player.use("Backpack");
       //error("----Satchel Deployed"@ %client.objective);
    }
    else if (%player.thrownChargeId) //lets run
    {
       %satchelCharge = %player.thrownChargeId;
       %targPos = %satchelCharge.getWorldBoxCenter();
	   %client.setDangerLocation(%targPos, 30);
       %client.needEquipment = true;
       //error("----Satchel Gonna Blow Running"@ %player.thrownChargeId);
    }

    if(!%player.thrownChargeId) // lets move to target
    {
	      %client.stepMove(%task.location, 8.0);
		 %task.setMonitorFreq(30);
//           error("----Satchel, moving to area"@ %client.objective);
    }

   //see if we're supposed to be engaging anyone...
//   if (!AIClientIsAlive(%client.getEngageTarget()) && AIClientIsAlive(%client.shouldEngage))
//      %client.setEngageTarget(%client.shouldEngage);
//   trace(0);

}

function createDefaultSatchel(%object, %weight1, %weight2)
{
   %objective = new AIObjective(AIOBlowUP)
   {
      dataBlock = "AIObjectiveMarker";
      description = "Satchel the " @ %object.getDataBlock().getName();
		targetObject = %object.getName();
		targetObjectId = %object;
		targetClientId = -1;
		weightLevel1 = %weight1;
		weightLevel2 = %weight2;
      location = %object.getWorldBoxCenter();
		offense = true;
		equipment = "SatchelCharge";
		buyEquipmentSet = "LightInfiltratorSet";
	};

   if(%object.missionTypesList !$= "")
      %objective.gameType = %object.missionTypesList;

   %objective.position = %objective.location;
   return %objective;
}
};
$EquipConfigIndex = -1;
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "SatchelCharge";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "Shocklance";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "Grenade";
$AIEquipmentSet[LightInfiltratorSet, $EquipConfigIndex++] = "Mine";

//******************************************************************************
// End of Satchel Package
//******************************************************************************


//******************************************************************************
//***** Missile Target Objective Package
//******************************************************************************
// This is used against Turret bases, medium sensors and large sensors
package Missile_Target {
//------------------------------
// new objective  AIMissileObject
function AIOMissileObject::weight(%this, %client, %level, %minWeight, %inventoryStr)
{
   // if were playing CnH, check who owns this
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.isHidden() || %this.targetObjectId.team == %client.team)
      return 0;

   //make sure the player is still alive!!!!!
   if (! AIClientIsAlive(%client))
      return 0;

   //no need to attack if the object is already destroyed
   if (!isObject(%this.targetObjectId) || %this.targetObjectId.getDamageState() $= "Destroyed")
      return 0;
   else
	{
		//if this bot is linked to a human who has issued this command, up the weight
		if (%this.issuedByClientId == %client.controlByHuman)
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
			{
				if ($AIWeightHumanIssuedCommand < %minWeight)
					return 0;
				else
					%weight = $AIWeightHumanIssuedCommand;
			}
			else
			{
				// calculate the default...
				%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
				if (%weight < $AIWeightHumanIssuedCommand)
					%weight = $AIWeightHumanIssuedCommand;
			}
		}
		else
		{
			//make sure we have the potential to reach the minWeight
			if (!AIODefault::QuickWeight(%this, %client, %level, %minWeight))
				return 0;

			// calculate the default...
			%weight = AIODefault::weight(%this, %client, %level, %inventoryStr);
		}

		return %weight;
	}
}

function AIOMissileObject::assignClient(%this, %client)
{
   %client.objectiveTask = %client.addTask(AIMissileObject);
   %client.objectiveTask.initFromObjective(%this, %client);
}

function AIOMissileObject::unassignClient(%this, %client)
{
   %client.removeTask(%client.objectiveTask);
   %client.objectiveTask = "";
}


//------------------------------------------------------------------------------
function AIMissileObject::initFromObjective(%task, %objective, %client)
{
   %task.baseWeight = %client.objectiveWeight;
   %task.targetObject = %objective.targetObjectId;
   %task.equipment = %objective.equipment;
	%task.buyEquipmentSet = %objective.buyEquipmentSet;
	%task.desiredEquipment = %objective.desiredEquipment;
	%task.issuedByClient = %objective.issuedByClientId;

	//initialize other task vars
	%task.sendMsg = true;
	%task.sendMsgTime = 0;
}
function AIMissileObject::weight(%task, %client)
{
   %task.setWeightFreq(100);
   %task.setMonitorFreq(30);
	//update the task weight
	if (%task == %client.objectiveTask)
		%task.baseWeight = %client.objectiveWeight;

   %task.setWeight(%task.baseWeight);
}

function AIMissileObject::assume(%task, %client)
{
   %task.setWeightFreq(15);
   %task.setMonitorFreq(5);
   %client.needEquipment = AINeedEquipment(%task.equipment, %client);

//	//even if we don't *need* equipemnt, see if we should buy some...
//	if (! %client.needEquipment && %task.buyEquipmentSet !$= "")
//	{
//		//see if we could benefit from inventory
//		%needArmor = AIMustUseRegularInvStation(%task.desiredEquipment, %client);
//		%result = AIFindClosestInventory(%client, %needArmor);
//		%closestInv = getWord(%result, 0);
//		%closestDist = getWord(%result, 1);
//		if (AINeedEquipment(%task.desiredEquipment, %client) && %closestInv > 0)
//		{
//			//find where we are
//			%clientPos = %client.player.getWorldBoxCenter();
//			%objPos = %task.targetObject.getWorldBoxCenter();
//			%distToObject = %client.getPathDistance(%objPos);
//
//			if (%distToObject < 0 || %closestDist < %distToObject)
//				%client.needEquipment = true;
//		}
//	}

	//mark the current time for the buy inventory state machine
	%task.buyInvTime = getSimTime();
}

function AIMissileObject::retire(%task, %client)
{
   %client.setTargetObject(-1);
}

function AIMissileObject::monitor(%task, %client)
{
   //first, buy the equipment
   %hasMissile = (%client.player.getInventory("MissileLauncher") > 0) && (%client.player.getInventory("MissileLauncherAmmo") > 0);
   if (%client.needEquipment)
   {
	   %task.setMonitorFreq(5);
		if (%task.equipment !$= "")
			%equipmentList = %task.equipment;
		else
			%equipmentList = %task.desiredEquipment;
      %result = AIBuyInventory(%client, %equipmentList, %task.buyEquipmentSet, %task.buyInvTime);
		if (%result $= "InProgress")
			return;
		else if (%result $= "Finished")
		{
		   %task.setMonitorFreq(15);
			%client.needEquipment = false;
		}
		else if (%result $= "Failed")
		{
	      //if this task is the objective task, choose a new objective
	      if (%task == %client.objectiveTask)
	      {
	         AIUnassignClient(%client);
	         Game.AIChooseGameObjective(%client);
	      }
			return;
		}
   }
	//if we made it past the inventory buying, reset the inv time
	%task.buyInvTime = getSimTime();

	//chat
	if (%task.sendMsg)
	{
		if (%task.sendMsgTime == 0)
			%task.sendMsgTime = getSimTime();
		else if (getSimTime() - %task.sendMsgTime > 7000)
		{
			%task.sendMsg = false;
		   if (%client.isAIControlled())
			{
				if (%task.chat !$= "")
				{
					%chatMsg = getWord(%task.chat, 0);
					%chatTemplate = getWord(%task.chat, 1);
					if (%chatTemplate !$= "")
						AIMessageThreadTemplate(%chatTemplate, %chatMsg, %client, -1);
					else
						AIMessageThread(%task.chat, %client, -1);
				}
				else if (%task.targetObject > 0)
				{
					%type = %task.targetObject.getDataBlock().getName();
					if (%type $= "TurretBaseLarge")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackTurrets", %client, -1);
					else if (%type $= "SensorLargePulse")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
					else if (%type $= "SensorMediumPulse")
						AIMessageThreadTemplate("AttackBase", "ChatSelfAttackSensors", %client, -1);
				}
			}
		}
	}

   //set the target object
   if (isObject(%task.targetObject) && %task.targetObject.getDamageState() !$= "Destroyed")
   {
      %client.setTargetObject(%task.targetObject, 350, "MissileNoLock");
      echo("Missile Target  Valid Target not Destroyed");

      //move towards the object until we're within range
      if (!%client.targetInRange())
         %client.stepMove(%task.targetObject.getWorldBoxCenter(), 8.0);
      else
		{
			//dissolve the human control link
			if (%task == %client.objectiveTask)
				aiReleaseHumanControl(%client.controlByHuman, %client);

         %client.stop();
		}
   }
   else
   {
      %client.setTargetObject(-1);
      %client.stop();

      //if this task is the objective task, choose a new objective
      if (%task == %client.objectiveTask)
      {
         AIUnassignClient(%client);
         Game.AIChooseGameObjective(%client);
      }
   }
}

function createDefaultMissile(%object, %weight1, %weight2)
{
   %objective = new AIObjective(AIOMissileObject)
   {
      dataBlock = "AIObjectiveMarker";
      description = "Missile the " @ %object.getDataBlock().getName();
		targetObject = %object.getName();
		targetObjectId = %object;
		targetClientId = -1;
		weightLevel1 = %weight1;
		weightLevel2 = %weight2;
      location = %object.getWorldBoxCenter();
		offense = true;
		equipment = "MissileLancher MissileLancherAmmo";
		buyEquipmentSet = "HeavyMissileSet";
	};

   if(%object.missionTypesList !$= "")
      %objective.gameType = %object.missionTypesList;

   %objective.position = %objective.location;
   return %objective;
}
};

$EquipConfigIndex = -1;
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "Heavy";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "AmmoPack";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "Plasma";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "PlasmaAmmo";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "MissileLauncher";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "MissileLauncherAmmo";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "Mortar";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "MortarAmmo";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "Grenade";
$AIEquipmentSet[HeavyMissileSet, $EquipConfigIndex++] = "Mine";


//******************************************************************************
//***** Deploy Pulse Sensor Objective Package
//******************************************************************************
// This is used against Turret bases, medium sensors and large sensors
//==============================================================================
//  This one is alot easier.  All you have todo is set the equipment to the
//  pulse sensor or the motion sensor.  The code doesnt care what the deployable
//  this should work even for MODS If you wanted to make your own.
//==============================================================================
$EquipConfigIndex = -1;
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "PulseSensorDeployable";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "GrenadeLauncher";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "GrenadeLauncherAmmo";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "ELFGun";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "Grenade";
$AIEquipmentSet[MediumPulseSet, $EquipConfigIndex++] = "Mine";

$EquipConfigIndex = -1;
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "Medium";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "MotionSensorDeployable";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "GrenadeLauncher";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "GrenadeLauncherAmmo";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "ELFGun";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "Grenade";
$AIEquipmentSet[MediumMotionSet, $EquipConfigIndex++] = "Mine";
// This makes the CC chat work for bots
$ObjectiveTable['DeploySensor', type]               = "AIODeployEquipment";
$ObjectiveTable['DeploySensor', weightLevel1]       = 2500;
$ObjectiveTable['DeploySensor', weightLevel2]       = 1000;
$ObjectiveTable['DeploySensor', weightLevel3]       = 500;
$ObjectiveTable['DeploySensor', weightLevel4]       = 100;
$ObjectiveTable['DeploySensor', equipment]          = "PulseSensorDeployable";
$ObjectiveTable['DeploySensor', desiredEquipment]   = "PulseSensorDeployable";
$ObjectiveTable['DeploySensor', buyEquipmentSet]    = "MediumPulseSet";
$ObjectiveTable['DeploySensor', offense]            = "false";
$ObjectiveTable['DeploySensor', defense]            = "true";
$ObjectiveTable['DeploySensor', assignTimeout]      = "5000";   // period allowed for humans to ack
$ObjectiveTable['DeploySensor', maxAssigned]        = "2";      // not added if at least this many playrs have ack'd
$ObjectiveTable['DeploySensor', chat]               = "DefendBase ChatTaskSetupSensors";      // not added if at least this many playrs have ack'd

$ObjectiveTable['DeployMotion', type]               = "AIODeployEquipment";
$ObjectiveTable['DeployMotion', weightLevel1]       = 2500;
$ObjectiveTable['DeployMotion', weightLevel2]       = 1000;
$ObjectiveTable['DeployMotion', weightLevel3]       = 500;
$ObjectiveTable['DeployMotion', weightLevel4]       = 100;
$ObjectiveTable['DeployMotion', equipment]          = "MotionSensorDeployable";
$ObjectiveTable['DeployMotion', desiredEquipment]   = "MotionSensorDeployable";
$ObjectiveTable['DeployMotion', buyEquipmentSet]    = "MediumMotionSet";
$ObjectiveTable['DeployMotion', offense]            = "false";
$ObjectiveTable['DeployMotion', defense]            = "true";
$ObjectiveTable['DeployMotion', assignTimeout]      = "5000";   // period allowed for humans to ack
$ObjectiveTable['DeployMotion', maxAssigned]        = "2";      // not added if at least this many playrs have ack'd
$ObjectiveTable['DeployMotion', chat]               = "DefendBase ChatTaskSetupSensors";      // not added if at least this many playrs have ack'd

$CommandTask['Location', 8, text]               = "Deploy Motion";
$CommandTask['Location', 8, tag]                = 'DeployMotion';
$CommandTask['Location', 8, hotkey]             = "x";

$TaskDescription['DeployMotion']       = 'Deploy Motion';

// here is a goodie.  Its a set that you will have to add into your defend location
// or attack location but with my support script you can have BOts that actually cloak
$EquipConfigIndex = -1;
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "Light";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "CloakingPack";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "Chaingun";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "ChaingunAmmo";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "Disc";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "DiscAmmo";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "Shocklance";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "TargetingLaser";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "RepairKit";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "Grenade";
$AIEquipmentSet[LightAssassinSet, $EquipConfigIndex++] = "Mine";

